pub struct AlertCategory(/* private fields */);Expand description
Bitmask categories for filtering alerts.
Implementations
Sourceimpl AlertCategory
impl AlertCategory
Sourcepub const STATUS: AlertCategory
pub const STATUS: AlertCategory
Torrent lifecycle: added, removed, paused, resumed, finished, state changes.
Sourcepub const ERROR: AlertCategory
pub const ERROR: AlertCategory
Errors from torrents, trackers, storage.
Sourcepub const PEER: AlertCategory
pub const PEER: AlertCategory
Peer connect/disconnect/ban events.
Sourcepub const TRACKER: AlertCategory
pub const TRACKER: AlertCategory
Tracker announce replies and errors.
Sourcepub const STORAGE: AlertCategory
pub const STORAGE: AlertCategory
Storage/file operations.
Sourcepub const DHT: AlertCategory
pub const DHT: AlertCategory
DHT bootstrap and peer discovery.
Sourcepub const STATS: AlertCategory
pub const STATS: AlertCategory
Periodic session/torrent statistics.
Sourcepub const PIECE: AlertCategory
pub const PIECE: AlertCategory
Piece-level events (verified, hash-failed).
Sourcepub const BLOCK: AlertCategory
pub const BLOCK: AlertCategory
Block-level events (high volume).
Sourcepub const PERFORMANCE: AlertCategory
pub const PERFORMANCE: AlertCategory
Performance warnings.
Sourcepub const PORT_MAPPING: AlertCategory
pub const PORT_MAPPING: AlertCategory
Port mapping (UPnP/NAT-PMP).
Sourcepub const I2P: AlertCategory
pub const I2P: AlertCategory
I2P session events.
Sourcepub const ALL: AlertCategory
pub const ALL: AlertCategory
All categories enabled.
Sourceimpl AlertCategory
impl AlertCategory
Sourcepub const fn empty() -> AlertCategory
pub const fn empty() -> AlertCategory
Get a flags value with all bits unset.
Sourcepub const fn all() -> AlertCategory
pub const fn all() -> AlertCategory
Get a flags value with all known bits set.
Sourcepub const fn bits(&self) -> u32
pub const fn bits(&self) -> u32
Get the underlying bits value.
The returned value is exactly the bits set in this flags value.
Sourcepub const fn from_bits(bits: u32) -> Option<AlertCategory>
pub const fn from_bits(bits: u32) -> Option<AlertCategory>
Convert from a bits value.
This method will return None if any unknown bits are set.
Sourcepub const fn from_bits_truncate(bits: u32) -> AlertCategory
pub const fn from_bits_truncate(bits: u32) -> AlertCategory
Convert from a bits value, unsetting any unknown bits.
Sourcepub const fn from_bits_retain(bits: u32) -> AlertCategory
pub const fn from_bits_retain(bits: u32) -> AlertCategory
Convert from a bits value exactly.
Sourcepub fn from_name(name: &str) -> Option<AlertCategory>
pub fn from_name(name: &str) -> Option<AlertCategory>
Get a flags value with the bits of a flag with the given name set.
This method will return None if name is empty or doesn’t
correspond to any named flag.
Sourcepub const fn intersects(&self, other: AlertCategory) -> bool
pub const fn intersects(&self, other: AlertCategory) -> bool
Whether any set bits in other are also set in self.
Sourcepub const fn contains(&self, other: AlertCategory) -> bool
pub const fn contains(&self, other: AlertCategory) -> bool
Whether all set bits in other are also set in self.
Sourcepub fn insert(&mut self, other: AlertCategory)
pub fn insert(&mut self, other: AlertCategory)
The bitwise or (|) of the bits in self and other.
Sourcepub fn remove(&mut self, other: AlertCategory)
pub fn remove(&mut self, other: AlertCategory)
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
remove won’t truncate other, but the ! operator will.
Sourcepub fn toggle(&mut self, other: AlertCategory)
pub fn toggle(&mut self, other: AlertCategory)
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub fn set(&mut self, other: AlertCategory, value: bool)
pub fn set(&mut self, other: AlertCategory, value: bool)
Call insert when value is true or remove when value is false.
Sourcepub const fn intersection(self, other: AlertCategory) -> AlertCategory
pub const fn intersection(self, other: AlertCategory) -> AlertCategory
The bitwise and (&) of the bits in self and other.
Sourcepub const fn union(self, other: AlertCategory) -> AlertCategory
pub const fn union(self, other: AlertCategory) -> AlertCategory
The bitwise or (|) of the bits in self and other.
Sourcepub const fn difference(self, other: AlertCategory) -> AlertCategory
pub const fn difference(self, other: AlertCategory) -> AlertCategory
The intersection of self with the complement of other (&!).
This method is not equivalent to self & !other when other has unknown bits set.
difference won’t truncate other, but the ! operator will.
Sourcepub const fn symmetric_difference(self, other: AlertCategory) -> AlertCategory
pub const fn symmetric_difference(self, other: AlertCategory) -> AlertCategory
The bitwise exclusive-or (^) of the bits in self and other.
Sourcepub const fn complement(self) -> AlertCategory
pub const fn complement(self) -> AlertCategory
The bitwise negation (!) of the bits in self, truncating the result.
Sourceimpl AlertCategory
impl AlertCategory
Sourcepub const fn iter(&self) -> Iter<AlertCategory>
pub const fn iter(&self) -> Iter<AlertCategory>
Yield a set of contained flags values.
Each yielded flags value will correspond to a defined named flag. Any unknown bits will be yielded together as a final flags value.
Sourcepub const fn iter_names(&self) -> IterNames<AlertCategory>
pub const fn iter_names(&self) -> IterNames<AlertCategory>
Yield a set of contained named flags values.
This method is like iter, except only yields bits in contained named flags.
Any unknown bits, or bits not corresponding to a contained flag will not be yielded.