pub struct ScanResult {
pub candidates: Vec<bool>,
pub candidate_count: u32,
pub total_pieces: u32,
pub files_found: u32,
pub files_total: u32,
}Expand description
Result of a fast file-size pre-scan.
Fields
candidates: Vec<bool>Per-piece bitmap: true if all constituent files exist with correct sizes.
candidate_count: u32Number of candidate pieces (count of true entries).
total_pieces: u32Total pieces in the torrent.
files_found: u32Number of files found on disk with correct size.
files_total: u32Total number of files in the torrent metadata.